@@ -91,6 +91,7 @@ class InfluxDBClient(_BaseClient):
         :param debug: Enable verbose logging of http requests
         :param enable_gzip: Enable Gzip compression for http requests. Currently, only the "Write" and "Query" endpoints
                             supports the Gzip compression.
+        :key config_name: Name of the configuration section of the configuration file
         :key str proxy_headers: A dictionary containing headers that will be sent to the proxy. Could be used for proxy
                                 authentication.
         :key urllib3.util.retry.Retry retries: Set the default retry strategy that is used for all HTTP requests
@@ -264,7 +265,7 @@ class InfluxDBClient(_BaseClient):
 
         :param write_options: Write API configuration
         :param point_settings: settings to store default tags
-        :key success_callback: The callable ``callback`` to run after successfully writen a batch.
+        :key success_callback: The callable ``callback`` to run after having successfully written a batch.
 
                                The callable must accept two arguments:
                                     - `Tuple`: ``(bucket, organization, precision)``
@@ -272,7 +273,7 @@ class InfluxDBClient(_BaseClient):
 
                                **[batching mode]**
 
-        :key error_callback: The callable ``callback`` to run after unsuccessfully writen a batch.
+        :key error_callback: The callable ``callback`` to run after having unsuccessfully written a batch.
 
                              The callable must accept three arguments:
                                 - `Tuple`: ``(bucket, organization, precision)``
