@@ -9,6 +9,7 @@ from typing import List
 
 from influxdb_client import TasksService, Task, TaskCreateRequest, TaskUpdateRequest, LabelResponse, LabelMapping, \
     AddResourceMemberRequestBody, RunManually, Run, LogEvent
+from influxdb_client.client._pages import _Paginated
 
 
 class TasksApi(object):
@@ -25,7 +26,7 @@ class TasksApi(object):
         return task
 
     def find_tasks(self, **kwargs):
-        """List all tasks.
+        """List all tasks up to set limit (max 500).
 
         :key str name: only returns tasks with the specified name
         :key str after: returns tasks after specified ID
@@ -37,6 +38,19 @@ class TasksApi(object):
         """
         return self._service.get_tasks(**kwargs).tasks
 
+    def find_tasks_iter(self, **kwargs):
+        """Iterate over all tasks with pagination.
+
+        :key str name: only returns tasks with the specified name
+        :key str after: returns tasks after specified ID
+        :key str user: filter tasks to a specific user ID
+        :key str org: filter tasks to a specific organization name
+        :key str org_id: filter tasks to a specific organization ID
+        :key int limit: the number of tasks in one page
+        :return: Tasks iterator
+        """
+        return _Paginated(self._service.get_tasks, lambda response: response.tasks).find_iter(**kwargs)
+
     def create_task(self, task: Task = None, task_create_request: TaskCreateRequest = None) -> Task:
         """Create a new task."""
         if task_create_request is not None:
