@@ -250,15 +250,18 @@ class WriteApi(_BaseWriteApi):
         self._success_callback = kwargs.get('success_callback', None)
         self._error_callback = kwargs.get('error_callback', None)
         self._retry_callback = kwargs.get('retry_callback', None)
+        self._window_scheduler = None
 
         if self._write_options.write_type is WriteType.batching:
             # Define Subject that listen incoming data and produces writes into InfluxDB
             self._subject = Subject()
 
+            self._window_scheduler = ThreadPoolScheduler(1)
             self._disposable = self._subject.pipe(
                 # Split incoming data to windows by batch_size or flush_interval
                 ops.window_with_time_or_count(count=write_options.batch_size,
-                                              timespan=timedelta(milliseconds=write_options.flush_interval)),
+                                              timespan=timedelta(milliseconds=write_options.flush_interval),
+                                              scheduler=self._window_scheduler),
                 # Map  window into groups defined by 'organization', 'bucket' and 'precision'
                 ops.flat_map(lambda window: window.pipe(
                     # Group window by 'organization', 'bucket' and 'precision'
@@ -434,11 +437,15 @@ You can use native asynchronous version of the client:
                 # Have we reached the upper limit?
                 if waited >= max_wait_time:
                     logger.warning(
-                            "Reached max_close_wait (%s seconds) waiting for batches to finish writing. Force closing",
-                            max_wait_time
-                        )
+                        "Reached max_close_wait (%s seconds) waiting for batches to finish writing. Force closing",
+                        max_wait_time
+                    )
                     break
 
+        if self._window_scheduler:
+            self._window_scheduler.executor.shutdown(wait=False)
+            self._window_scheduler = None
+
         if self._disposable:
             self._disposable = None
         pass
@@ -507,7 +514,7 @@ You can use native asynchronous version of the client:
     def _post_write(self, _async_req, bucket, org, body, precision, **kwargs):
 
         return self._write_service.post_write(org=org, bucket=bucket, body=body, precision=precision,
-                                              async_req=_async_req, content_encoding="identity",
+                                              async_req=_async_req,
                                               content_type="text/plain; charset=utf-8",
                                               **kwargs)
 
@@ -564,6 +571,7 @@ You can use native asynchronous version of the client:
         # Remove rx
         del state['_subject']
         del state['_disposable']
+        del state['_window_scheduler']
         del state['_write_service']
         return state
 
